Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4559)

Unified Diff: chrome/test/chromedriver/chrome/mobile_emulation_override_manager.h

Issue 288193004: [Chromedriver] Add Device Metrics override support to ChromeDriver via Capabilities (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/chromedriver/chrome/mobile_emulation_override_manager.h
diff --git a/chrome/test/chromedriver/chrome/geolocation_override_manager.h b/chrome/test/chromedriver/chrome/mobile_emulation_override_manager.h
similarity index 51%
copy from chrome/test/chromedriver/chrome/geolocation_override_manager.h
copy to chrome/test/chromedriver/chrome/mobile_emulation_override_manager.h
index 0ce63539d5fef7ab4a456d1e3e54f396fd3076ee..e691cb4e961fcfee55df1f2feaa4f7c20dfb0cfa 100644
--- a/chrome/test/chromedriver/chrome/geolocation_override_manager.h
+++ b/chrome/test/chromedriver/chrome/mobile_emulation_override_manager.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2013 The Chromium Authors. All rights reserved.
+// Copyright (c) 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_TEST_CHROMEDRIVER_CHROME_GEOLOCATION_OVERRIDE_MANAGER_H_
-#define CHROME_TEST_CHROMEDRIVER_CHROME_GEOLOCATION_OVERRIDE_MANAGER_H_
+#ifndef CHROME_TEST_CHROMEDRIVER_CHROME_MOBILE_EMULATION_OVERRIDE_MANAGER_H_
+#define CHROME_TEST_CHROMEDRIVER_CHROME_MOBILE_EMULATION_OVERRIDE_MANAGER_H_
#include <string>
@@ -17,17 +17,16 @@ class DictionaryValue;
}
class DevToolsClient;
-struct Geoposition;
+struct DeviceMetrics;
class Status;
// Overrides the geolocation, if requested, for the duration of the
// given |DevToolsClient|'s lifetime.
-class GeolocationOverrideManager : public DevToolsEventListener {
+class MobileEmulationOverrideManager : public DevToolsEventListener {
public:
- explicit GeolocationOverrideManager(DevToolsClient* client);
- virtual ~GeolocationOverrideManager();
-
- Status OverrideGeolocation(const Geoposition& geoposition);
+ MobileEmulationOverrideManager(DevToolsClient* client,
+ const DeviceMetrics* device_metrics);
+ virtual ~MobileEmulationOverrideManager();
// Overridden from DevToolsEventListener:
virtual Status OnConnected(DevToolsClient* client) OVERRIDE;
@@ -39,9 +38,9 @@ class GeolocationOverrideManager : public DevToolsEventListener {
Status ApplyOverrideIfNeeded();
DevToolsClient* client_;
- scoped_ptr<Geoposition> overridden_geoposition_;
+ const DeviceMetrics* overridden_device_metrics_;
- DISALLOW_COPY_AND_ASSIGN(GeolocationOverrideManager);
+ DISALLOW_COPY_AND_ASSIGN(MobileEmulationOverrideManager);
};
-#endif // CHROME_TEST_CHROMEDRIVER_CHROME_GEOLOCATION_OVERRIDE_MANAGER_H_
+#endif // CHROME_TEST_CHROMEDRIVER_CHROME_MOBILE_EMULATION_OVERRIDE_MANAGER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -17,17 +17,16 @@ class DictionaryValue;
class Status;
-// Overrides the geolocation, if requested, for the duration of the
+// Overrides the device metrics, if requested, for the duration of the
// given |DevToolsClient|'s lifetime.